#include "itkImageSeriesReader.h"
#include "itkGDCMImageIO.h"
#include "itkGDCMSeriesFileNames.h"

#include <time.h>


int main( int argc, char* argv[] )
{
    if( argc < 2 )
    {
        std::cerr << "Usage: " << argv[0] << " DicomDirectory " << std::endl;
        return EXIT_FAILURE;
    }
    
    std::cout << "ITK's version: " << ITK_VERSION_STRING << std::endl;
    

    // Typedefs for itk image format and reader type
    typedef signed short       PixelType;
    const unsigned int         Dimension = 3;
    typedef itk::Image< PixelType, Dimension >      ImageType;
    typedef itk::ImageSeriesReader< ImageType >     ReaderType;
    typedef itk::GDCMImageIO       ImageIOType;
    typedef itk::GDCMSeriesFileNames     NamesGeneratorType;
    typedef std::vector<std::string>  FileNamesContainer;

    // We instantiate the objects
    ReaderType::Pointer reader = ReaderType::New();
    ImageIOType::Pointer dicomIO = ImageIOType::New();
    NamesGeneratorType::Pointer nameGenerator = NamesGeneratorType::New();

    clock_t start,end;
    
    // We give the input directory where the images remain, which is the program argument
    std::cout << "Reading directory: ";
    start = clock();
    nameGenerator->SetInputDirectory( argv[1] );
    end = clock();
    std::cout << end - start << std::endl;

    FileNamesContainer fileNames = nameGenerator->GetInputFileNames();

    reader->SetImageIO( dicomIO );
    reader->SetFileNames( fileNames );
    
    try
    {
        std::cout << "Updating: " ;
        start = clock();

        reader->Update();
        
        end = clock();
        std::cout << end - start << std::endl;
    }
    catch (itk::ExceptionObject &ex)
    {
        std::cerr << "Series Reader Exception: " << std::endl << ex.GetDescription() << std::endl;
    }
    

    return 0;
}
